Crate lox_zkp
lox_zkp
0.8.4
All Items
Sections
Note
Crate Items
Modules
Macros
Structs
Enums
Crate
lox_zkp

Note
Modules

toolbox
Contains lower-level tools that allow programmable specification of proof statements.
Macros

define_
proof
Creates a module with code required to produce a non-interactive zero-knowledge proof statement, to serialize it to wire format, to parse from wire format, and to verify the proof or batch-verify multiple proofs.
Structs

Batchable
Proof
A Schnorr proof in batchable format.
Compact
Proof
A Schnorr proof in compact format.
Transcript
A transcript of a public-coin argument.
Enums

Proof
Error
An error during proving or verification, such as a verification failure.